# Python ROUGE Implementation by Google Research

This is a package to reproduce ROUGE-1.5.5 perl functionality in pure python.
Tests are provided to ensure agreement with original perl script output.
It is written by members of the Google Brain Team of Google Research.

The original source is at this [repository](https://github.com/google-research/google-research/tree/master/rouge).
